¿Qué es OiRA? | OiRA

Temas

# ¿Qué es OiRA?

## ¿Es la primera vez que accede a OiRA?

Aquí encontrará una breve introducción sobre la evaluación de riesgos y cómo OiRA puede ayudarle a gestionarla.

## ¿En qué consiste la evaluación de riesgos?

La evaluación de riesgos, además de constituir la base para gestionar de forma eficaz la seguridad y la salud, es clave para reducir los accidentes de trabajo y las enfermedades profesionales. Si se aplica adecuadamente, puede mejorar la seguridad y la salud en los puestos de trabajo y el rendimiento de las empresas en general.

En Europa, la seguridad y la salud de los trabajadores debe protegerse mediante la evaluación y la gestión de los riesgos en el trabajo. Las empresas tienen la obligación legal de garantizar la seguridad y la salud de los trabajadores en todos los aspectos relacionados con el trabajo y de efectuar evaluaciones de riesgos. Por lo tanto, cualquier empresa debe llevar a cabo una evaluación de riesgos y elaborar un plan de acción. Para realizar una evaluación eficaz de los riesgos de un puesto de trabajo, todos los implicados deben tener claro:

- El contexto y los conceptos jurídicos.
- El proceso utilizado para evaluar los riesgos.
- La función que desempeñarán los principales agentes que intervienen en el proceso.

Los trabajadores o sus representantes tienen derecho a ser consultados sobre los mecanismos para realizar la evaluación de riesgos y participar en su proceso.

Puede encontrar más información sobre la evaluación de riesgos y sobre la participación de los trabajadores o sus representantes en el proceso de evaluación de riesgos en la página web del proyecto OiRA.

## ¿Qué es la herramienta OiRA?

OiRA significa ‘evaluación interactiva de riesgos en línea’ (del inglés Online interactive Risk Assessment). Se trata de una aplicación web que le permite realizar una evaluación de riesgos para la salud y la seguridad de su puesto de trabajo.

## ¿A quién se dirige OiRA?

Cualquier persona puede utilizar OiRA para evaluar los riesgos relacionados con la salud y la seguridad que pueden existir en su puesto de trabajo.

Sin embargo, la herramienta ha sido concebida para aportar el máximo valor a las empresas más pequeñas. Además, se ha desarrollado específicamente para ayudarlas a evaluar los riesgos en el trabajo y a elaborar una evaluación de riesgos documentada que incluya un plan de acción adaptado a los requisitos del centro de trabajo.

## ¿Qué debo hacer?

Complete varios pasos en el proceso de evaluación de riesgos con OiRA:

- Preparación: algunas herramientas incluyen preguntas sobre el perfil para adaptar OiRA a las especificidades de cada centro de trabajo. Cuando conteste a las preguntas sobre el perfil, la herramienta se adaptará a su situación específica y le mostrará los módulos aplicables.

- Participación: toda evaluación de riesgos debe realizarse con la participación activa de los trabajadores. La herramienta le ofrece la posibilidad de imprimir el texto completo de la evaluación de riesgos o algunas de sus partes para informar a los trabajadores y recabar sus comentarios.

- Identificación de riesgos: OiRA le presentará posibles riesgos o problemas de salud y seguridad que podrían plantearse en el puesto de trabajo. Al responder a las declaraciones o preguntas con un sí o un no, usted indicará si existen estos peligros o problemas. También puede dejar una pregunta sin responder y contestarla más adelante.

- Evaluación: algunas herramientas requieren que jerarquice los riesgos identificados. Existen diferentes formas de hacerlo, en función de las decisiones que hayan adoptado nuestros socios o desarrolladores nacionales de OiRA y de su enfoque específico. Algunas herramientas también establecen automáticamente la jerarquización de los riesgos en segundo plano (usted puede modificar estas prioridades).

- Plan de acción: para cada riesgo identificado, la herramienta requiere que usted opte por una o varias medidas para eliminarlo o reducirlo. La mayoría de las herramientas le proponen algunas medidas. También puede optar por introducir sus propias medidas.

- Informe: tiene la obligación legal de documentar su evaluación de riesgos. En la sección de informes encontrará varios documentos que le ayudarán a llevar un registro de su evaluación de riesgos y hacer un seguimiento de las acciones o medidas que ha decidido aplicar para eliminar o mitigar los riesgos identificados.

## ¿Cuánto tiempo es necesario?

No se puede determinar el tiempo que va a requerir una evaluación con carácter general, ya que las herramientas difieren en función de los sectores y de los países.

Sin embargo, puede dedicar el tiempo que tenga disponible para realizar una evaluación y, después, retomarla cuando sea conveniente desde el punto en el que la dejó.

## ¿Por qué debo registrarme?

El primer paso que requiere la aplicación al iniciar la primera evaluación de riesgos será crear una cuenta OiRA, un proceso sencillo y rápido.

Al registrarse, podrá iniciar sesión en cualquier momento para seguir con las evaluaciones anteriores o iniciar otras nuevas. Si ya está registrado, puede obtener una evaluación de riesgos impresa, exacta y actualizada en cualquier momento.

## ¿Es necesario preparar algo?

No se necesita ningún tipo de preparación específica para empezar a utilizar la herramienta, pero debe dedicar tiempo a pensar quién llevará a cabo la evaluación de riesgos, cómo van a participar los trabajadores en el proceso, etc.

Scroll to top Load toolbar…
Back

## 2-what-is-oira.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More